@@ -24,8 +24,8 @@
  */
 
 module jdk.internal.vm.compiler {
-    // source file: file:///build/java-openjdk/src/jdk11u-jdk-11.0.3+4/src/jdk.internal.vm.compiler/share/classes/module-info.java
-    //              file:///build/java-openjdk/src/jdk11u-jdk-11.0.3+4/build/linux-x86_64-normal-server-release/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
+    // source file: file:///build/java-openjdk/src/jdk12u-jdk-12.0.1+12/src/jdk.internal.vm.compiler/share/classes/module-info.java
+    //              file:///build/java-openjdk/src/jdk12u-jdk-12.0.1+12/build/linux-x86_64-server-release/support/gensrc/jdk.internal.vm.compiler/module-info.java.extra
     requires java.instrument;
     requires java.management;
     requires jdk.internal.vm.ci;
@@ -65,6 +65,7 @@ module jdk.internal.vm.compiler {
         jdk.aot,
         jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.phases to jdk.aot;
+    exports org.graalvm.compiler.phases.common.jmx to jdk.internal.vm.compiler.management;
     exports org.graalvm.compiler.phases.tiers to jdk.aot;
     exports org.graalvm.compiler.printer to jdk.aot;
     exports org.graalvm.compiler.replacements to jdk.aot;
@@ -84,12 +85,14 @@ module jdk.internal.vm.compiler {
     uses org.graalvm.compiler.hotspot.HotSpotGraalManagementRegistration;
     uses org.graalvm.compiler.nodes.graphbuilderconf.NodeIntrinsicPluginFactory;
     uses org.graalvm.compiler.options.OptionDescriptors;
-    uses org.graalvm.compiler.serviceprovider.GraalServices.JMXService;
+    uses org.graalvm.compiler.phases.common.jmx.HotSpotMBeanOperationProvider;
+    uses org.graalvm.compiler.serviceprovider.JMXService;
     provides jdk.vm.ci.services.JVMCIServiceLocator with org.graalvm.compiler.hotspot.HotSpotGraalJVMCIServiceLocator;
     provides org.graalvm.compiler.code.DisassemblerProvider with
         org.graalvm.compiler.code.HexCodeFileDisassemblerProvider,
         org.graalvm.compiler.hotspot.meta.HotSpotDisassemblerProvider;
     provides org.graalvm.compiler.core.match.MatchStatementSet with
+        org.graalvm.compiler.core.aarch64.AArch64NodeMatchRules_MatchStatementSet,
         org.graalvm.compiler.core.amd64.AMD64NodeMatchRules_MatchStatementSet,
         org.graalvm.compiler.core.sparc.SPARCNodeMatchRules_MatchStatementSet;
     provides org.graalvm.compiler.debug.DebugHandlersFactory with org.graalvm.compiler.printer.GraalDebugHandlersFactory;
@@ -113,14 +116,12 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.nodes.PluginFactory_AcquiredCASLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_AllocaNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_BeginLockScopeNode,
-        org.graalvm.compiler.hotspot.nodes.PluginFactory_ComputeObjectAddressNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_CurrentJavaThreadNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_CurrentLockNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DeoptimizeCallerNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_DimensionsNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_EndLockScopeNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_FastAcquireBiasedLockNode,
-        org.graalvm.compiler.hotspot.nodes.PluginFactory_GetObjectAddressNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_GraalHotSpotVMConfigNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_JumpToExceptionHandlerInCallerNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_JumpToExceptionHandlerNode,
@@ -128,11 +129,6 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.nodes.PluginFactory_PatchReturnAddressNode,
         org.graalvm.compiler.hotspot.nodes.PluginFactory_VMErrorNode,
         org.graalvm.compiler.hotspot.PluginFactory_HotSpotBackend,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_ArrayCopyCallNode,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_ArrayCopySnippets,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_ArrayCopyWithSlowPathNode,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_CheckcastArrayCopyCallNode,
-        org.graalvm.compiler.hotspot.replacements.arraycopy.PluginFactory_GenericArrayCopyCallNode,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_AESCryptSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_AssertionSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_CipherBlockChainingSubstitutions,
@@ -145,15 +141,14 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.replacements.PluginFactory_MonitorSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_NewObjectSnippets,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ObjectSubstitutions,
-        org.graalvm.compiler.hotspot.replacements.PluginFactory_StringToBytesSnippets,
+        org.graalvm.compiler.hotspot.replacements.PluginFactory_SHA2Substitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_ThreadSubstitutions,
         org.graalvm.compiler.hotspot.replacements.PluginFactory_WriteBarrierSnippets,
         org.graalvm.compiler.hotspot.replacements.profiling.PluginFactory_ProbabilisticProfileSnippets,
         org.graalvm.compiler.hotspot.replacements.profiling.PluginFactory_ProfileSnippets,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_CreateExceptionStub,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_ExceptionHandlerStub,
-        org.graalvm.compiler.hotspot.stubs.PluginFactory_NewArrayStub,
-        org.graalvm.compiler.hotspot.stubs.PluginFactory_NewInstanceStub,
+        org.graalvm.compiler.hotspot.stubs.PluginFactory_ForeignCallSnippets,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_StubUtil,
         org.graalvm.compiler.hotspot.stubs.PluginFactory_UnwindExceptionToCallerStub,
         org.graalvm.compiler.nodes.debug.PluginFactory_DynamicCounterNode,
@@ -167,12 +162,15 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.extended.PluginFactory_UnsafeCopyNode,
         org.graalvm.compiler.nodes.java.PluginFactory_ArrayLengthNode,
         org.graalvm.compiler.nodes.java.PluginFactory_DynamicNewArrayNode,
+        org.graalvm.compiler.nodes.java.PluginFactory_InstanceOfNode,
         org.graalvm.compiler.nodes.java.PluginFactory_NewArrayNode,
         org.graalvm.compiler.nodes.java.PluginFactory_RegisterFinalizerNode,
         org.graalvm.compiler.nodes.memory.address.PluginFactory_OffsetAddressNode,
         org.graalvm.compiler.nodes.memory.PluginFactory_MemoryAnchorNode,
         org.graalvm.compiler.nodes.PluginFactory_BreakpointNode,
+        org.graalvm.compiler.nodes.PluginFactory_ComputeObjectAddressNode,
         org.graalvm.compiler.nodes.PluginFactory_DeoptimizeNode,
+        org.graalvm.compiler.nodes.PluginFactory_GetObjectAddressNode,
         org.graalvm.compiler.nodes.PluginFactory_PauseNode,
         org.graalvm.compiler.nodes.PluginFactory_PiArrayNode,
         org.graalvm.compiler.nodes.PluginFactory_PiNode,
@@ -180,11 +178,22 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.nodes.PluginFactory_SnippetAnchorNode,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64FloatArithmeticSnippets,
         org.graalvm.compiler.replacements.aarch64.PluginFactory_AArch64IntegerArithmeticSnippets,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOfNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64ArrayIndexOf,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64MathSubstitutions,
-        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringIndexOfNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1InflateNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringLatin1Substitutions,
         org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringSubstitutions,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringUTF16CompressNode,
+        org.graalvm.compiler.replacements.amd64.PluginFactory_AMD64StringUTF16Substitutions,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyCallNode,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopySnippets,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_ArrayCopyWithSlowPathNode,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_CheckcastArrayCopyCallNode,
+        org.graalvm.compiler.replacements.arraycopy.PluginFactory_GenericArrayCopyCallNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayCompareToNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayEqualsNode,
+        org.graalvm.compiler.replacements.nodes.PluginFactory_ArrayRegionEqualsNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_AssertionNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_BinaryMathIntrinsicNode,
         org.graalvm.compiler.replacements.nodes.PluginFactory_BitScanForwardNode,
@@ -195,10 +204,11 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.replacements.nodes.PluginFactory_UnaryMathIntrinsicNode,
         org.graalvm.compiler.replacements.PluginFactory_ConstantStringIndexOfSnippets,
         org.graalvm.compiler.replacements.PluginFactory_Log,
+        org.graalvm.compiler.replacements.PluginFactory_ReplacementsUtil,
         org.graalvm.compiler.replacements.PluginFactory_SnippetCounterNode;
     provides org.graalvm.compiler.options.OptionDescriptors with
-        org.graalvm.compiler.core.amd64.AMD64NodeLIRBuilder_OptionDescriptors,
         org.graalvm.compiler.core.common.GraalOptions_OptionDescriptors,
+        org.graalvm.compiler.core.common.SpeculativeExecutionAttacksMitigations_OptionDescriptors,
         org.graalvm.compiler.core.common.spi.JavaConstantFieldProvider_OptionDescriptors,
         org.graalvm.compiler.core.common.util.CompilationAlarm_OptionDescriptors,
         org.graalvm.compiler.core.GraalCompilerOptions_OptionDescriptors,
@@ -214,6 +224,7 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.hotspot.CompilerConfigurationFactory_OptionDescriptors,
         org.graalvm.compiler.hotspot.debug.BenchmarkCounters_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotBackend_OptionDescriptors,
+        org.graalvm.compiler.hotspot.HotSpotCompiledCodeBuilder_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotGraalCompilerFactory_OptionDescriptors,
         org.graalvm.compiler.hotspot.HotSpotTTYStreamProvider_OptionDescriptors,
         org.graalvm.compiler.hotspot.meta.HotSpotAOTProfilingPlugin_OptionDescriptors,
@@ -228,10 +239,6 @@ module jdk.internal.vm.compiler {
         org.graalvm.compiler.lir.alloc.lsra.LinearScanEliminateSpillMovePhase_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.LinearScan_OptionDescriptors,
         org.graalvm.compiler.lir.alloc.lsra.OptimizingLinearScanWalker_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.DefaultTraceRegisterAllocationPolicy_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.lsra.TraceLinearScanPhase_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.TraceBuilderPhase_OptionDescriptors,
-        org.graalvm.compiler.lir.alloc.trace.TraceRegisterAllocationPhase_OptionDescriptors,
         org.graalvm.compiler.lir.amd64.phases.StackMoveOptimizationPhase_OptionDescriptors,
         org.graalvm.compiler.lir.asm.CompilationResultBuilder_OptionDescriptors,
         org.graalvm.compiler.lir.BailoutAndRestartBackendException_OptionDescriptors,
