@@ -343,6 +343,25 @@ public class FormatData_fa extends ListResourceBundle {
             { "buddhist.TimePatterns", metaValue_TimePatterns },
             { "standalone.MonthAbbreviations", metaValue_standalone_MonthNames },
             { "timezone.regionFormat", "\u0648\u0642\u062a {0}" },
+            { "long.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0 \u0647\u0632\u0627\u0631",
+                    "00 \u0647\u0632\u0627\u0631",
+                    "000 \u0647\u0632\u0627\u0631",
+                    "0 \u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "00 \u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "000 \u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "0 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "00 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "000 \u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "0 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "00 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "000 \u0647\u0632\u0627\u0631\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                }
+            },
             { "buddhist.QuarterNarrows", metaValue_QuarterNarrows },
             { "roc.narrow.AmPmMarkers", metaValue_narrow_AmPmMarkers },
             { "standalone.QuarterNames", metaValue_QuarterNames },
@@ -404,6 +423,25 @@ public class FormatData_fa extends ListResourceBundle {
             { "roc.AmPmMarkers", metaValue_AmPmMarkers },
             { "java.time.roc.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
             { "java.time.buddhist.DatePatterns", metaValue_java_time_buddhist_DatePatterns },
+            { "short.CompactNumberPatterns",
+                new String[] {
+                    "",
+                    "",
+                    "",
+                    "0\u00a0\u0647\u0632\u0627\u0631",
+                    "00\u00a0\u0647\u0632\u0627\u0631",
+                    "000\u00a0\u0647\u0632\u0627\u0631",
+                    "0\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "00\u00a0\u0645\u06cc\u0644\u06cc\u0648\u0646",
+                    "000\u00a0\u0645",
+                    "0\u00a0\u0645",
+                    "00\u00a0\u0645",
+                    "000\u00a0\u0645\u06cc\u0644\u06cc\u0627\u0631\u062f",
+                    "0\u00a0\u062a\u0631\u06cc\u0644\u06cc\u0648\u0646",
+                    "00\u00a0\u062a",
+                    "000\u00a0\u062a",
+                }
+            },
             { "calendarname.gregorian", metaValue_calendarname_gregorian },
             { "timezone.regionFormat.daylight", "\u0648\u0642\u062a \u062a\u0627\u0628\u0633\u062a\u0627\u0646\u06cc {0}" },
             { "DatePatterns",
